aboutsummaryrefslogtreecommitdiffstats
path: root/audio/engine_2.asm
diff options
context:
space:
mode:
authordannye <33dannye@gmail.com>2019-09-03 22:36:02 -0500
committerdannye <33dannye@gmail.com>2019-09-03 22:36:02 -0500
commit362bba7642431d87371cb86c9442e7636fcd287b (patch)
treedcbccdf05a241727033b66816f31bd2007258063 /audio/engine_2.asm
parentMake pitch_sweep pitch change argument consistent with the other signed magni... (diff)
downloadpokeyellow-362bba7642431d87371cb86c9442e7636fcd287b.tar.gz
pokeyellow-362bba7642431d87371cb86c9442e7636fcd287b.tar.xz
pokeyellow-362bba7642431d87371cb86c9442e7636fcd287b.zip
Rename dnote to drum_note and dspeed to drum_speed
Diffstat (limited to 'audio/engine_2.asm')
-rw-r--r--audio/engine_2.asm10
1 files changed, 5 insertions, 5 deletions
diff --git a/audio/engine_2.asm b/audio/engine_2.asm
index df719c67..026ade7c 100644
--- a/audio/engine_2.asm
+++ b/audio/engine_2.asm
@@ -658,8 +658,8 @@ Audio2_note:
jr nz, Audio2_note_length ; if not noise channel
ld a, d
and $f0
- cp $b0 ; is this command a dnote?
- jr z, .dnote
+ cp $b0 ; is this command a drum_note?
+ jr z, .drum_note
jr nc, Audio2_note_length ; no
; this executes when on the noise channel and
@@ -668,7 +668,7 @@ Audio2_note:
; and the lower nybble is the length minus 1 (0-15)
; however, this doesn't work for instrument #2 because the command id
; is captured by the noise_note command (command id $2x)
; this essentially acts like a dnote command that is only 1 byte
; instead of 2 and can only be used with instruments 1 and 3 through 10
; this is unused by the game
swap a
@@ -681,12 +681,12 @@ Audio2_note:
push bc
jr .playDnote
-.dnote
+.drum_note
ld a, d
and $f
push af
push bc
- call Audio2_GetNextMusicByte ; get dnote instrument
+ call Audio2_GetNextMusicByte ; get drum_note instrument
.playDnote
ld d, a
ld a, [wDisableChannelOutputWhenSfxEnds]
@@ -668,7 +668,7 @@ Audio2_note:
; however, this doesn't work for instrument #2 because the command id
; is captured by the noise_note command (command id $2x)
- ; this essentially acts like a dnote command that is only 1 byte
+ ; this essentially acts like a drum_note command that is only 1 byte
; instead of 2 and can only be used with instruments 1 and 3 through 10
; this is unused by the game